==> COMPSs_1.3.tar.gz: COMPSs/Dependencies/extrae/doc/user-guide/internals.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate internals original text with physical files.


$key = q/sec:XMLSectionOthers/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_DynInst_Intermediate/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:FAQ/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Configuration/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:BasicAPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Examples/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionCUDA/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:EnvVars_in_XML/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Examples_DynInst/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_static_Intermediate/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:NetworkPerformanceCounters/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:XML/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Merging/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_DynInst_Intermediate_MPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:OPENCLinstrumentedroutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_static_link/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLcell/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionPACX/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_CUDA/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:EnvironmentVariables_continued/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:JavaBindings/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:AdvancedJavaBindings/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:ProcessorPerformanceCounters/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:RunningTraceDynInst/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:ExtendedAPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:QuickStart/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:PPEside/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Examples_LDPRELOAD/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionStorage/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_Linux/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionUF/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionMPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:API/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:AvailableExtraeLIBS/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_LDPRELOAD_Final/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionTraceControl/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:EnvironmentVariables/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionOPENCL/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionMerge/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionTraceConfiguration/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:SPEside/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionCallers/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:MPIinstrumentedroutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionSampling/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionBursts/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:InstrumentedRoutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionIO/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:RunningTraceNOTDynInst/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionBuffer/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:OpenMPruntimesinstrumented/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Introduction/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:MergerDescription/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:wholeXML/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionDynamicMemory/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionPerformanceCounters/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:OperatingSystemAccounting/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:PackageDescription/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionOpenMP/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Configuration/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_AIX/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Examples_static/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:EnvVar/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:CUDAinstrumentedroutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

1;

==> COMPSs_2.2.tar.gz: COMPSs/Dependencies/extrae/doc/user-guide/internals.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate internals original text with physical files.


$key = q/tab:AvailableExtraeLIBS/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLIntelPEBS/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:RunningTraceDynInst/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionMerge/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:QuickStart/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:RunningTraceNOTDynInst/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:ExtendedAPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionStorage/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_LDPRELOAD_Final/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionPerformanceCounters/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:BasicAPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Configuration/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:InstrumentedRoutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_AIX/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Examples_static/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_static_Intermediate/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/fig:Overhead_Extrae_3_3_0/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:EnvVars_in_XML/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionCUDA/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionOPENCL/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Introduction/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Examples/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionDynamicMemory/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Examples_LDPRELOAD/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:FAQ/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionMPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:submitbug/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:Examples_DynInst/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:OperatingSystemAccounting/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:NetworkPerformanceCounters/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:PackageDescription/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:EnvironmentVariables/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionBursts/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:MergerDescription/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:OpenMPruntimesinstrumented/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionIO/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:API/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionUF/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionTraceConfiguration/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:JavaBindings/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_static_link/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_Linux/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:ProcessorPerformanceCounters/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Merging/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:RegressionTests/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionSampling/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_CUDA/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionOpenMP/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:CUDAinstrumentedroutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionOthers/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:OPENCLinstrumentedroutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_DynInst_Intermediate/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:MPIinstrumentedroutines/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:AdvancedJavaBindings/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/subsec:Examples_DynInst_Intermediate_MPI/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/tab:EnvironmentVariables_continued/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionTraceControl/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionCallers/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Configuration/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:XML/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:EnvVar/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:wholeXML/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:XMLSectionBuffer/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

$key = q/cha:Overhead/;
$ref_files{$key} = "$dir".q|user-guide.html|; 
$noresave{$key} = "$nosave";

1;
